Module executor

Module executor 

EVM executors

Executors are structs that hook gasometer and the EVM core together. It also handles the call stacks in EVM.

Currently only a stack-based (customizable) executor is provided.

Modules

stack
A stack-based executor with customizable state. A memory-based state is provided, but can be replaced by a custom implementation, for example one interacting with a database.